% Driver for Stiletto

% Smith, L. A., 1997, The maintenance of uncertainty, in G. Cini Castognoli
% and A. Provenzale, editors, Past and Present Variability of the 
% Solar-Terrestrial system: Measurement, Data Analysis and Theoretical Models,
% volume CXXXIII of Proceedings of the International School of Physics, 
% 177-246, Amsterdam, Italian Physical Society.

% Equations:
% x_{i+1} = (x_i + 1.0/a)*exp(a*(1.0 - x_i) - 1.0) - 1.0/a + y_i
% y_{i+1} = b*x_i - y_i*s

% Written by Jim Hansen, Feb 2003 for 12.990 students

% Specify the dimension of the system
dim = 2;

% Specify the initial conditions
x = [0.1 0.2];

% Specify the parameter values (a, b, c, s)
par = [3.0 0.3 0.0 0.0];

% Specify the length of integration
steps = 2^12;

% Integrate the equations over length steps to remove any transient behavior
for i=1:steps
 xout=stil(x,par,dim);
 x=xout;
end

% Integrate the equations over length steps and record state for plotting
for i=1:steps
 xout=stil(x,par,dim);
 state(i,:)=xout;
 x=xout;
end

plot(state(:,1),state(:,2),'.')
xlabel('x');ylabel('y');title('Stiletto map');

print -djpeg90 stil.jpg
