% Driver for Tinkerbell

% Alligood, K. T., T. D. Sauer, and J. A. York, 1996, Chaos:
% An introduction to dynamical systems, Springer-Verlag.

% Equations:
% x_{i+1} = x_i*x_i - y_i*y_i + a*x_i + b*y_i
% y_{i+1} = c*x_i*y_i - d*x_i + e*y_i

% Written by Jim Hansen, Feb 2003 for 12.990 students

% Specify the dimension of the system
dim = 2;

% Specify the initial conditions
x = [0.1 0.2];

% Specify the parameter values (a, b, c, d, e)
par = [0.9 0.6013 2.0 2.0 0.5];

% Specify the length of integration
steps = 2^12;

% Integrate the equations over length steps to remove any transient behavior
for i=1:steps
 xout=tink(x,par,dim);
 x=xout;
end

% Integrate the equations over length steps and record state for plotting
for i=1:steps
 xout=tink(x,par,dim);
 state(i,:)=xout;
 x=xout;
end

plot(state(:,1),state(:,2),'.')
xlabel('x');ylabel('y');title('Tinkerbell map');

print -djpeg90 tink.jpg
